@@ -1,12 +1,12 @@
 package SPOPS::Import;
 
-# $Id: Import.pm,v 3.2 2002/10/10 04:00:35 lachoy Exp $
+# $Id: Import.pm,v 3.3 2003/01/02 06:00:25 lachoy Exp $
 
 use strict;
 use base qw( Class::Accessor Class::Factory );
 use SPOPS::Exception qw( spops_error );
 
-$SPOPS::Import::VERSION  = sprintf("%d.%02d", q$Revision: 3.2 $ =~ /(\d+)\.(\d+)/);
+$SPOPS::Import::VERSION  = sprintf("%d.%02d", q$Revision: 3.3 $ =~ /(\d+)\.(\d+)/);
 
 use constant AKEY => '_attrib';
 
@@ -227,4 +227,4 @@ it under the same terms as Perl itself.
 
 =head1 AUTHORS
 
-Chris Winters <chris@cwinters.com>
+Chris Winters E<lt>chris@cwinters.comE<gt>
