@@ -1,6 +1,6 @@
 package SPOPS::Import::DBI::Table;
 
-# $Id: Table.pm,v 3.1 2002/09/03 11:43:22 lachoy Exp $
+# $Id: Table.pm,v 3.2 2003/01/02 06:00:23 lachoy Exp $
 
 use strict;
 use base qw( SPOPS::Import );
@@ -8,7 +8,7 @@ use Data::Dumper qw( Dumper );
 use SPOPS::Exception;
 use SPOPS::Import::DBI::TableTransform;
 
-$SPOPS::Import::DBI::Table::VERSION  = sprintf("%d.%02d", q$Revision: 3.1 $ =~ /(\d+)\.(\d+)/);
+$SPOPS::Import::DBI::Table::VERSION  = sprintf("%d.%02d", q$Revision: 3.2 $ =~ /(\d+)\.(\d+)/);
 
 my @FIELDS = qw( database_type transforms print_only );
 SPOPS::Import::DBI::Table->mk_accessors( @FIELDS );
@@ -279,4 +279,4 @@ it under the same terms as Perl itself.
 
 =head1 AUTHORS
 
-Chris Winters <chris@cwinters.com>
+Chris Winters E<lt>chris@cwinters.comE<gt>
